@@ -1,6 +1,9 @@
+from feynml.propagator import Propagator
+from feynml.vertex import Vertex
 from pyhepmc import GenEvent
 
-from pyfeyn2.feynmandiagram import FeynmanDiagram, Leg, Propagator, Vertex
+from feynml.feynmandiagram import FeynmanDiagram
+from feynml.leg import Leg
 
 
 def _vertex_id_wrap(idd):
